@@ -150,7 +150,7 @@ class LDAPModel():
             try:
                 res = getattr(self._entry, attr)
             except AttributeError:
-                if default is None:
+                if default is not None:
                     return default
                 else:
                     raise AttributeNotFound()
@@ -178,6 +178,12 @@ class LDAPModel():
         """
         return self._entry.save()
 
+    def delete(self):
+        """
+           Delete this entry on the LDAP server.
+        """
+        return self._entry.delete()
+
     @classmethod
     def _from_entry(cls, entry):
         obj = cls(None, "")
